#include "..\script_component.hpp"

/*
 * Function: ramdb_db_fnc_hashGetAll
 * Author: Creedcoder, J.Schmidt
 * Edit: 07.15.2024
 * Copyright © 2024 Creedcoder, J.Schmidt, All rights reserved
 *
 * Do not edit without permission!
 *
 * This work is licensed under the Creative Commons Attribution-NonCommercial-ShareAlike 4.0 International License.
 * To view a copy of this license, vist https://creativecommons.org/licenses/by-nc-sa/4.0/ or send a letter to Creative Commons,
 * PO Box 1866, Mountain View, CA 94042
 *
 * [Description]
 * Get all fields and values of hash stored in key from DB.
 *
 * Arguments:
 * 0: Name of function to return data <STRING> (default: "")
 * 1: Unscheduled environment <BOOL> (default: false)
 * 2: NetID of target to return data from function <STRING> (default: nil)
 *
 * Return Value:
 * N/A
 *
 * Examples:
 * ["ramdb_db_fnc_test", false] call ramdb_db_fnc_hashGetAll (Server or Singleplayer Only)
 * ["ramdb_db_fnc_test", false, netId player] remoteExecCall ["ramdb_db_fnc_hashGetAll", 2, false] (Multiplayer Only)
 *
 * Public: Yes
 */

params [["_function", "", [""]], ["_call", false, [false]], ["_netId", "", [""]]];

diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashGetAll' Function: '%1', Call: '%2', NetId: '%3'", _function, _call, _netId];

if (_function isEqualTo "") exitWith {
	diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashGetAll' Invalid Input for Function '%1'", _function];
};

private _return = "";

if (_netId != "") then {
	diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashGetAll' Using NetId: '%1'", _netId];
	if (_call) then {
		_return = "ArmaRAMDb" callExtension ["hgetall", [_function, _netId, _call]];
	} else {
		_return = "ArmaRAMDb" callExtension ["hgetall", [_function, _netId]];
	};
} else {
	diag_log text "ArmaRAMDb: 'ramdb_db_fnc_hashGetAll' Using current player";
	if (_call) then {
		_return = "ArmaRAMDb" callExtension ["hgetall", [_function, _call]];
	} else {
		_return = "ArmaRAMDb" callExtension ["hgetall", [_function]];
	};
};

diag_log text format ["ArmaRAMDb: 'ramdb_db_fnc_hashGetAll' Return: '%1'", _return];
[(_return select 0)] call FUNC(scheduler);